@@ -252,7 +252,7 @@ else:
                              [(constr.lb, constr.ub, constr.name) for constr in self.model.constraints])
 
         def test_config_gets_copied_too(self):
-            self.assertEquals(self.model.configuration.verbosity, 0)
+            self.assertEqual(self.model.configuration.verbosity, 0)
             self.model.configuration.verbosity = 1
             model_copy = copy.copy(self.model)
             self.assertEqual(model_copy.configuration.verbosity, 1)
